==> munit-maven-plugin-1.3.0-sources.jar: org/mule/runner/printer/TextResultPrinter.java <==
package org.mule.runner.printer;


import org.apache.commons.lang3.StringUtils;
import org.apache.maven.plugin.logging.Log;
import org.mule.runner.model.RunResult;
import org.mule.runner.model.SuiteResult;
import org.mule.runner.model.TestResult;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintStream;

public class TextResultPrinter extends FileResultPrinter {

    private static final float MILLIS_FACTOR = 1000.0f;
    private static final String SUITE_RESULT_MESSAGE = "Tests run: %d - Failures: %d - Errors: %d - Skipped: %d - Time elapsed: %.3f sec";
    private static final String TEST_ERROR_MESSAGE = "ERROR - Test %s finished with an Error.\n";
    private static final String TEST_FAILED_MESSAGE = "FAILURE - Test %s finished with a Failure.\n";
    private static final String TEST_IGNORED_MESSAGE = "SKIPPED - Test %s was Skipped.\n";
    private static final String TEST_SUCCESS_MESSAGE = "SUCCESS - Test %s finished Successfully.\n";

    private static final String TXT_REPORT_HEADER = "munit.";

    public TextResultPrinter(File reportBasePath, File suiteBasePath, Log log) {
        super(reportBasePath, suiteBasePath, log);
    }

    public void print(RunResult runResult) {
        try {
            for (SuiteResult suiteResult : runResult.getSuites()) {
                printSuiteResult(suiteResult);
            }
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    public void printSuiteResult(SuiteResult result) throws FileNotFoundException {
        String suiteRelativePath = getSuiteRelativePath(result.getSuitePath());
        String suiteReportName = suiteRelativePath.replace("/", ".");
        suiteReportName = suiteReportName.replace(".xml", ".txt");
        PrintStream out = getResultPrintStream(TXT_REPORT_HEADER + suiteReportName);
        for (TestResult testResult : result.getTests()) {
            printTestResult(testResult, out);
        }
        out.println();
        if(result.hasError() || result.hasFailed()){
            out.println(result.getCause());
        }
        String title = String.format(SUITE_RESULT_MESSAGE, result.getNumberOfTests(), result.getNumberOfFailures(), result.getNumberOfErrors(), result.getNumberOfIgnores(), result.getTime() / MILLIS_FACTOR);
        String titleFrame = StringUtils.repeat("=", title.length());
        out.println(titleFrame);
        out.println(title);
        out.println(titleFrame);
        out.flush();
    }

    public void printTestResult(TestResult testResult, PrintStream out) {
        if (testResult.hasError()) {
            out.format(TEST_ERROR_MESSAGE, testResult.getTestName());
            out.println(testResult.getCause());
        } else if (testResult.hasFailed()) {
            out.format(TEST_FAILED_MESSAGE, testResult.getTestName());
            out.println(testResult.getCause());
        } else if (testResult.isIgnored()) {
            out.format(TEST_IGNORED_MESSAGE, testResult.getTestName());
        } else {
            out.format(TEST_SUCCESS_MESSAGE, testResult.getTestName());
        }
        out.flush();
    }


}

==> munit-maven-plugin-1.3.6-sources.jar: org/mule/runner/printer/TextResultPrinter.java <==
package org.mule.runner.printer;


import org.apache.commons.lang3.StringUtils;
import org.apache.maven.plugin.logging.Log;
import org.mule.runner.model.RunResult;
import org.mule.runner.model.SuiteResult;
import org.mule.runner.model.TestResult;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintStream;

public class TextResultPrinter extends FileResultPrinter {

    private static final float MILLIS_FACTOR = 1000.0f;
    private static final String SUITE_RESULT_MESSAGE = "Tests run: %d - Failures: %d - Errors: %d - Skipped: %d - Time elapsed: %.3f sec";
    private static final String TEST_ERROR_MESSAGE = "ERROR - Test %s finished with an Error.\n";
    private static final String TEST_FAILED_MESSAGE = "FAILURE - Test %s finished with a Failure.\n";
    private static final String TEST_IGNORED_MESSAGE = "SKIPPED - Test %s was Skipped.\n";
    private static final String TEST_SUCCESS_MESSAGE = "SUCCESS - Test %s finished Successfully.\n";

    private static final String TXT_REPORT_HEADER = "munit.";

    public TextResultPrinter(File reportBasePath, File suiteBasePath, File projectBasePath, Log log) {
        super(reportBasePath, suiteBasePath, projectBasePath, log);
    }

    public void print(RunResult runResult) {
        try {
            for (SuiteResult suiteResult : runResult.getSuites()) {
                printSuiteResult(suiteResult);
            }
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    public void printSuiteResult(SuiteResult result) throws FileNotFoundException {
        String suiteRelativePath = getSuiteRelativePath(result.getSuitePath());
        String suiteReportName = suiteRelativePath.replace("/", ".");
        suiteReportName = suiteReportName.replace(".xml", ".txt");
        PrintStream out = getResultPrintStream(TXT_REPORT_HEADER + suiteReportName);
        for (TestResult testResult : result.getTests()) {
            printTestResult(testResult, out);
        }
        out.println();
        if(result.hasError() || result.hasFailed()){
            out.println(result.getCause());
        }
        String title = String.format(SUITE_RESULT_MESSAGE, result.getNumberOfTests(), result.getNumberOfFailures(), result.getNumberOfErrors(), result.getNumberOfIgnores(), result.getTime() / MILLIS_FACTOR);
        String titleFrame = StringUtils.repeat("=", title.length());
        out.println(titleFrame);
        out.println(title);
        out.println(titleFrame);
        out.flush();
    }

    public void printTestResult(TestResult testResult, PrintStream out) {
        if (testResult.hasError()) {
            out.format(TEST_ERROR_MESSAGE, testResult.getTestName());
            out.println(testResult.getCause());
        } else if (testResult.hasFailed()) {
            out.format(TEST_FAILED_MESSAGE, testResult.getTestName());
            out.println(testResult.getCause());
        } else if (testResult.isIgnored()) {
            out.format(TEST_IGNORED_MESSAGE, testResult.getTestName());
        } else {
            out.format(TEST_SUCCESS_MESSAGE, testResult.getTestName());
        }
        out.flush();
    }


}
